; ********************************
; ***                          ***
; **                            **
; *   Statusanzeige - Routinen   *
; **                            **
; ***                          ***
; ********************************

status_Interrupt:

lds		Value, 0x0100							; Zhlerwert lesen
dec		Value
sts		0x0100, Value							; neuen Zhlerwert zurck schreiben

breq	status_Toggle

reti

status_Show:

lsl		Routine									; Fehlerroutine vorbereiten
sts		0x0101, Routine

lsl		Errorcode								; Fehlermeldung vorbereiten
sts		0x0102, Errorcode

sbr		Status, 0x01							; Status "Status eingeschaltet" setzen
sbr		Status, 0x02							; Status "Routine toggeln" setzen
sbr		Status, 0x04							; Status "Errorcode toggeln" setzen

ret

status_Toggle:

ldi		Value, 0x20								; Zhler Status zurck setzen
sts		0x0100, Value

sbrs	Status, 0x00							; Fehlermeldung eingeschaltet
reti											; Nein, also springe zurck

sbrc	Status, 0x01							; Status "Routine toggeln" gesetzt?
rcall	status_ToggleRoutine					; Ja, also springe

sbrc	Status, 0x02							; Status "Errorcode toggeln" gesetzt?
rcall	status_ToggleErrorcode					; Ja, also springe

sbrc	Status, 0x03							; Status "Pause" gesetzt?
rcall	status_Pause							; Ja, also springe

reti

status_ToggleRoutine:

in		Value, 0x18								; PortB lesen
ldi		Math, 0x01								; Pin1 (PortB0) toggeln
eor		Value, Math
out		0x18, Value

dec		Routine									; Routine aktualisieren
in		Value, 0x3f								; Statusregister lesen
sbrc	Value, 0x01								; Zeroflag gesetzt?
cbr		Status, 0x02							; Ja, also Status "Routine toggeln" zurck setzen

push	Status									; Status zwischen speichern
andi	Status, 0xf9							; Bits ausblenden
pop		Status									; Status zurck laden

cpi		Status, 0x01							; Status "Pause" aktivieren?
in		Value, 0x3f								; Statusregister lesen
sbrc	Value, 0x01								; Zeroflag gesetzt?
sbr		Status, 0x08							; Ja, also Status "Pause" setzen

ret

status_ToggleErrorcode:

in		Value, 0x18								; PortB lesen
ldi		Math, 0x02								; Pin2 (PortB1) toggeln
eor		Value, Math
out		0x18, Value

dec		Errorcode								; Errorcode aktualisieren
in		Value, 0x3f								; Statusregister lesen
sbrc	Value, 0x01								; Zeroflag gesetzt?
cbr		Status, 0x04							; Ja, also Status "Errorcode toggeln" zurck setzen

push	Status									; Status zwischen speichern
andi	Status, 0xf9							; Bits ausblenden
pop		Status									; Status zurck laden

cpi		Status, 0x01							; Status "Pause" aktivieren?
in		Value, 0x3f								; Statusregister lesen
sbrc	Value, 0x01								; Zeroflag gesetzt?
sbr		Status, 0x08							; Ja, also Status "Pause" setzen

ret

status_Pause:

lds		Value, 0x0103							; Zhlerwert lesen
dec		Value
sts		0x0103, Value							; neuen Zhlerwert zurck schreiben

in		Value, 0x3f								; Statusregister lesen
sbrs	Value, 0x01								; Zeroflag gesetzt?
ret												; Nein, also springe zurck

ldi		Value, 0x04								; Zhlerwert zurck setzen
sts		0x0103, Value

lds		Routine, 0x0101							; Zhler Routine zurck setzen
lds		Errorcode, 0x0102						; Zhler Errorcode zurck setzen

ldi		Status, 0x07							; Status zurck setzen

ret
